@@ -1,21 +1,17 @@
 import json
 import os
 
-from conan.api.model import ListPattern
 from conan.api.output import ConanOutput, cli_out_write, Color
 from conan.cli import make_abs_path
 from conan.cli.args import common_graph_args, validate_common_graph_args
 from conan.cli.command import conan_command, conan_subcommand
 from conan.cli.commands.list import prepare_pkglist_compact, print_serial
 from conan.cli.formatters.graph import format_graph_html, format_graph_json, format_graph_dot
+from conan.cli.formatters.graph.build_order_html import format_build_order_html
 from conan.cli.formatters.graph.graph_info_text import format_graph_info
+from conan.cli.printers import print_profiles
 from conan.cli.printers.graph import print_graph_packages, print_graph_basic
 from conan.errors import ConanException
-from conan.internal.deploy import do_deploys
-from conans.client.graph.graph import BINARY_MISSING
-from conans.client.graph.install_graph import InstallGraph
-from conans.errors import NotFoundException
-from conans.model.recipe_ref import ref_matches, RecipeReference
 
 
 def explain_formatter_text(data):
@@ -38,14 +34,15 @@ def explain_formatter_json(data):
 
 
 @conan_command(group="Consumer")
-def graph(conan_api, parser, *args):
+def graph(conan_api, parser, *args):  # noqa
     """
     Compute a dependency graph, without installing or building the binaries.
     """
 
 
-def cli_build_order(build_order):
+def cli_build_order(result):
     # TODO: Very simple cli output, probably needs to be improved
+    build_order = result["build_order"]
     build_order = build_order["order"] if isinstance(build_order, dict) else build_order
     for level in build_order:
         for item in level:
@@ -58,11 +55,12 @@ def cli_build_order(build_order):
                 cli_out_write(f"{item['ref']}:{item['package_id']} - {item['binary']}")
 
 
-def json_build_order(build_order):
-    cli_out_write(json.dumps(build_order, indent=4))
+def json_build_order(result):
+    cli_out_write(json.dumps(result["build_order"], indent=4))
 
 
-@conan_subcommand(formatters={"text": cli_build_order, "json": json_build_order})
+@conan_subcommand(formatters={"text": cli_build_order, "json": json_build_order,
+                              "html": format_build_order_html})
 def graph_build_order(conan_api, parser, subparser, *args):
     """
     Compute the build order of a dependency graph.
@@ -74,11 +72,7 @@ def graph_build_order(conan_api, parser, subparser, *args):
                            help='Reduce the build order, output only those to build. Use this '
                                 'only if the result will not be merged later with other build-order')
     args = parser.parse_args(*args)
-
-    # parameter validation
-    if args.requires and (args.name or args.version or args.user or args.channel):
-        raise ConanException("Can't use --name, --version, --user or --channel arguments with "
-                             "--requires")
+    validate_common_graph_args(args)
     if args.order_by is None:
         ConanOutput().warning("Please specify --order-by argument", warn_tag="deprecated")
 
@@ -112,12 +106,8 @@ def graph_build_order(conan_api, parser, subparser, *args):
 
     out = ConanOutput()
     out.title("Computing the build order")
-
-    install_graph = InstallGraph(deps_graph, order_by=args.order_by)
-    if args.reduce:
-        if args.order_by is None:
-            raise ConanException("--reduce needs --order-by argument defined")
-        install_graph.reduce()
+    install_graph = conan_api.graph.build_order(deps_graph, args.order_by, args.reduce,
+                                                profile_args=args)
     install_order_serialized = install_graph.install_build_order()
     if args.order_by is None:  # legacy
         install_order_serialized = install_order_serialized["order"]
@@ -126,11 +116,13 @@ def graph_build_order(conan_api, parser, subparser, *args):
                                                   clean=args.lockfile_clean)
     conan_api.lockfile.save_lockfile(lockfile, args.lockfile_out, cwd)
 
-    return install_order_serialized
+    return {"build_order": install_order_serialized,
+            "conan_error": install_graph.get_errors()}
 
 
-@conan_subcommand(formatters={"text": cli_build_order, "json": json_build_order})
-def graph_build_order_merge(conan_api, parser, subparser, *args):
+@conan_subcommand(formatters={"text": cli_build_order, "json": json_build_order,
+                              "html": format_build_order_html})
+def graph_build_order_merge(conan_api, parser, subparser, *args):  # noqa
     """
     Merge more than 1 build-order file.
     """
@@ -142,21 +134,14 @@ def graph_build_order_merge(conan_api, parser, subparser, *args):
     if not args.file or len(args.file) < 2:
         raise ConanException("At least 2 files are needed to be merged")
 
-    result = InstallGraph.load(make_abs_path(args.file[0]))
-    if result.reduced:
-        raise ConanException(f"Reduced build-order file cannot be merged: {args.file[0]}")
-    for f in args.file[1:]:
-        install_graph = InstallGraph.load(make_abs_path(f))
-        if install_graph.reduced:
-            raise ConanException(f"Reduced build-order file cannot be merged: {f}")
-        result.merge(install_graph)
+    files = [make_abs_path(f) for f in args.file]
+    result = conan_api.graph.build_order_merge(files, args.reduce)
 
-    if args.reduce:
-        result.reduce()
     install_order_serialized = result.install_build_order()
     if getattr(result, "legacy"):
         install_order_serialized = install_order_serialized["order"]
-    return install_order_serialized
+    return {"build_order": install_order_serialized,
+            "conan_error": result.get_errors()}
 
 
 @conan_subcommand(formatters={"text": format_graph_info,
@@ -184,7 +169,6 @@ def graph_info(conan_api, parser, subparser, *args):
     subparser.add_argument("--build-require", action='store_true', default=False,
                            help='Whether the provided reference is a build-require')
     args = parser.parse_args(*args)
-
     # parameter validation
     validate_common_graph_args(args)
     if args.format in ("html", "dot") and args.filter:
@@ -202,6 +186,7 @@ def graph_info(conan_api, parser, subparser, *args):
                                                partial=args.lockfile_partial,
                                                overrides=overrides)
     profile_host, profile_build = conan_api.profiles.get_profiles_from_args(args)
+    print_profiles(profile_host, profile_build)
 
     if path:
         deps_graph = conan_api.graph.load_graph_consumer(path, args.name, args.version,
@@ -229,12 +214,24 @@ def graph_info(conan_api, parser, subparser, *args):
         conan_api.lockfile.save_lockfile(lockfile, args.lockfile_out, cwd)
         if args.deployer:
             base_folder = args.deployer_folder or os.getcwd()
-            do_deploys(conan_api, deps_graph, args.deployer, None, base_folder)
+            conan_api.install.deploy(deps_graph, args.deployer, None, base_folder)
+
+    warn_msg = None
+    missing = set(str(n.ref.name) for n in deps_graph.nodes if n.binary == "Missing")
+    invalid = set(str(n.ref.name) for n in deps_graph.nodes if n.binary == "Invalid")
+    if missing or invalid:
+        warn_msg = "There are some error(s) in the graph:"
+        if missing:
+            warn_msg += f"\n    - Missing packages: {', '.join(missing)}"
+        if invalid:
+            warn_msg += f"\n    - Invalid packages: {', '.join(invalid)}"
 
     return {"graph": deps_graph,
             "field_filter": args.filter,
             "package_filter": args.package_filter,
-            "conan_api": conan_api}
+            "conan_api": conan_api,
+            "conan_error": str(deps_graph.error) if deps_graph.error else None,
+            "conan_warning": warn_msg}
 
 
 @conan_subcommand(formatters={"text": explain_formatter_text,
@@ -290,17 +287,8 @@ def graph_explain(conan_api, parser,  subparser, *args):
     print_graph_packages(deps_graph)
 
     ConanOutput().title("Retrieving and computing closest binaries")
-    # compute ref and conaninfo
-    missing = args.missing
-    for node in deps_graph.ordered_iterate():
-        if ((not missing and node.binary == BINARY_MISSING)   # First missing binary or
-                or (missing and ref_matches(node.ref, missing, is_consumer=None))):  # specified one
-            ref = node.ref
-            conaninfo = node.conanfile.info
-            break
-    else:
-        raise ConanException("There is no missing binary")
-
+    # compute ref and conaninfo of the first missing binary
+    ref, conaninfo = conan_api.graph.find_first_missing_binary(deps_graph, args.missing)
     pkglist = conan_api.list.explain_missing_binaries(ref, conaninfo, remotes)
 
     ConanOutput().title("Closest binaries")
@@ -376,48 +364,6 @@ def graph_outdated(conan_api, parser, subparser, *args):
     print_graph_basic(deps_graph)
 
     # Data structure to store info per library
-    dependencies = deps_graph.nodes[1:]
-    dict_nodes = {}
-
-    # When there are no dependencies command should stop
-    if len(dependencies) == 0:
-        return dict_nodes
-
-    ConanOutput().title("Checking remotes")
-
-    for node in dependencies:
-        dict_nodes.setdefault(node.name, {"cache_refs": set(), "version_ranges": [],
-                                          "latest_remote": None})["cache_refs"].add(node.ref)
-
-    for version_range in deps_graph.resolved_ranges.keys():
-        dict_nodes[version_range.name]["version_ranges"].append(version_range)
-
-    # find in remotes
-    _find_in_remotes(conan_api, dict_nodes, remotes)
-
-    # Filter nodes with no outdated versions
-    filtered_nodes = {}
-    for node_name, node in dict_nodes.items():
-        if node['latest_remote'] is not None and sorted(list(node['cache_refs']))[0] < \
-            node['latest_remote']['ref']:
-            filtered_nodes[node_name] = node
-
-    return filtered_nodes
-
-
-def _find_in_remotes(conan_api, dict_nodes, remotes):
-    for node_name, node_info in dict_nodes.items():
-        ref_pattern = ListPattern(node_name, rrev=None, prev=None)
-        for remote in remotes:
-            try:
-                remote_ref_list = conan_api.list.select(ref_pattern, package_query=None,
-                                                        remote=remote)
-            except NotFoundException:
-                continue
-            if not remote_ref_list.recipes:
-                continue
-            str_latest_ref = list(remote_ref_list.recipes.keys())[-1]
-            recipe_ref = RecipeReference.loads(str_latest_ref)
-            if (node_info["latest_remote"] is None
-                    or node_info["latest_remote"]["ref"] < recipe_ref):
-                node_info["latest_remote"] = {"ref": recipe_ref, "remote": remote.name}
+    # DO NOT USE this API call yet, it is not stable
+    outdated = conan_api.list.outdated(deps_graph, remotes)
+    return outdated
