@@ -1,7 +1,8 @@
 import os
 
+from conan.errors import ConanException
 from conan.internal import check_duplicated_generator
-from conan.internal.internal_tools import raise_on_universal_arch
+from conan.internal.internal_tools import is_universal_arch
 from conan.tools.apple.apple import is_apple_os, resolve_apple_flags, apple_extra_flags
 from conan.tools.build import cmd_args_to_string, save_toolchain_args
 from conan.tools.build.cross_building import cross_building
@@ -33,7 +34,6 @@ class GnuToolchain:
                helper so that it reads the information from the proper file.
         :param prefix: Folder to use for ``--prefix`` argument ("/" by default).
         """
-        raise_on_universal_arch(conanfile)
         self._conanfile = conanfile
         self._namespace = namespace
         self._is_apple_system = is_apple_os(self._conanfile)
@@ -66,6 +66,13 @@ class GnuToolchain:
         self.msvc_runtime_link_flags = []
         if llvm_clang_front(self._conanfile) == "clang":
             self.msvc_runtime_link_flags = ["-fuse-ld=lld-link"]
+
+        self._is_universal_arch = is_universal_arch(conanfile.settings.get_safe("arch"),
+                                                    conanfile.settings.possible_values().get("arch"))
+        if self._is_universal_arch and not is_apple_os(self._conanfile):
+            arch_str = conanfile.settings.get_safe('arch')
+            raise ConanException(f"Universal arch '{arch_str}' is only supported in Apple OSes")
+
         extra_configure_args = self._conanfile.conf.get("tools.gnu:extra_configure_args",
                                                         check_type=list,
                                                         default=[])
@@ -76,7 +83,7 @@ class GnuToolchain:
             "host": {"triplet": self._conanfile.conf.get("tools.gnu:host_triplet")},
             "build": {"triplet": self._conanfile.conf.get("tools.gnu:build_triplet")}
         }
-        self._is_cross_building = cross_building(self._conanfile)
+        self._is_cross_building = not self._is_universal_arch and cross_building(self._conanfile)
         if self._is_cross_building:
             compiler = self._conanfile.settings.get_safe("compiler")
             # Host triplet
@@ -104,12 +111,15 @@ class GnuToolchain:
         # Apple stuff
         is_cross_building_osx = (self._is_cross_building
                                  and conanfile.settings_build.get_safe('os') == "Macos"
-                                 and is_apple_os(conanfile))
-        min_flag, arch_flag, isysroot_flag = (
-            resolve_apple_flags(conanfile, is_cross_building=is_cross_building_osx)
+                                 and is_apple_os(conanfile)
+                                 and not self._is_universal_arch)
+
+        min_flag, arch_flags, isysroot_flag = (
+            resolve_apple_flags(conanfile, is_cross_building=is_cross_building_osx,
+                                is_universal=self._is_universal_arch)
         )
         # https://man.archlinux.org/man/clang.1.en#Target_Selection_Options
-        self.apple_arch_flag = arch_flag
+        self.apple_arch_flag = arch_flags
         # -isysroot makes all includes for your library relative to the build directory
         self.apple_isysroot_flag = isysroot_flag
         self.apple_min_version_flag = min_flag
